"use strict";

// 円形鋼管の計算
class steelPipe {
    // プロパティ: 円形鋼管の寸法 (mm)
    // d: 直径, t: 板厚
	constructor(d = 0, t = 0) {
		this.d = d;
		this.t = t;
    }
    validSize() {
        // 寸法のチェック
        // 戻り値 false: 寸法に誤りがある, true: 正常
        if ((this.d < 10.0) || (this.t < 0.1) || (this.d < 2 * this.t)) {
            return false;
        } else {
            return true;
        }
    }
    get Area() {
        // 戻り値: 断面積 (cm2)
        if (this.validSize) {
            // mm -> cm 
            let t = 0.1 * this.t;
            let r1 = 0.1 * this.d; // 外径
            let r2 = r1 - 2.0 * t; // 内径
            return (r1 * r1 - r2 * r2) * Math.PI / 4.0;
        } else {
            return 0;
        }
    }
    get Ixy() {
        // 戻り値: 断面2次モーメント (cm4)
        if (this.validSize) {
            // mm -> cm 
            let t = 0.1 * this.t;
            let r1 = 0.1 * this.d; // 外径
            let r2 = r1 - 2.0 * t; // 内径
            return (r1 * r1 * r1 * r1 - r2 * r2 * r2 * r2) * Math.PI / 64.0;
        } else {
            return 0;
        }
    }
    get Zxy() {
        // 戻り値: 断面係数 (cm3)
        if (this.validSize) {
            return this.Ixy / (0.1 * (this.d / 2.0));
        } else {
            return 0;
        }
    }
    getFc(lk = 0.0, f = 235) {
        // 長期許容圧縮応力度の計算
        // lk: 座屈長さ (m), f: F値 (N/mm2)
        // 戻り値: 長期許容圧縮応力度 (N/mm2)
        if ((!this.validSize) || (f < 0.1)) {
            return 0;
        } else if (lk < 0.1) {
            // 座屈を考慮しない
            return f / 1.5;
        }
        let ramda = Math.sqrt(2023265.5 / (0.6 * f)); // 限界細長比 Λ (E = 205000)
        let ixy = Math.sqrt(this.Ixy / this.Area); // 断面2次半径
        let ramda1 = 100.0 * lk / ixy; // 細長比 λ
        let ramda2 = Math.pow(ramda1 / ramda, 2); // (λ / Λ) ^ 2
        if (ramda1 < ramda) {
            // λ < Λ
            return f * (1.0 - 0.4 * ramda2) / (1.5 + 0.667 * ramda2);
        } else {
            // λ > Λ
            return 0.277 * f / ramda2;
        }
    }
    getNa(lk = 0.0, f = 235) {
        // 長期軸耐力の計算
        // lk: 座屈長さ (m), f: F値 (N/mm2)
        // 戻り値: 長期軸耐力 (kN)
        return 0.1 * this.Area * this.getFc(lk, f); // N -> kN
    }
    getMa(f = 235) {
        // 曲げ耐力の計算
        // 戻り値: 長期曲げ耐力 (kN.m)
        return 0.001 * this.Zxy * f / 1.5; // N.cm -> kN.m
    }
}